@@ -108,6 +108,7 @@ public:
     void updateButtonStatus(bool isDirty);
     void showMessage(const QString &text, KMessageWidget::MessageType type);
     void slotInvalidCollection();
+    void setCalendarCollection(const Akonadi::Collection &collection);
 
     /// ItemEditorUi methods
     bool containsPayloadIdentifiers(const QSet<QByteArray> &partIdentifiers) const override;
@@ -181,6 +182,11 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
     mIeResource = new IncidenceResource(mIeAttendee, mIeDateTime, mUi);
     mEditor->combine(mIeResource);
 
+    // Set the default collection
+    const qint64 colId = CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
+    const Akonadi::Collection col(colId);
+    setCalendarCollection(col);
+
     q->connect(mEditor, SIGNAL(showMessage(QString,KMessageWidget::MessageType)),
                SLOT(showMessage(QString,KMessageWidget::MessageType)));
     q->connect(mEditor, SIGNAL(dirtyStatusChanged(bool)),
@@ -215,6 +221,15 @@ void IncidenceDialogPrivate::slotInvalidCollection()
     showMessage(i18n("Select a valid collection first."), KMessageWidget::Warning);
 }
 
+void IncidenceDialogPrivate::setCalendarCollection(const Akonadi::Collection &collection)
+{
+    if (collection.isValid()) {
+        mCalSelector->setDefaultCollection(collection);
+    } else {
+        mCalSelector->setCurrentIndex(0);
+    }
+}
+
 void IncidenceDialogPrivate::showMessage(const QString &text, KMessageWidget::MessageType type)
 {
     mUi->mMessageWidget->setText(text);
@@ -584,8 +599,8 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
 
     if (incidence->attendeeCount() > 1     // >1 because you won't drink alone
         && !me.isNull() && (me.status() == KCalendarCore::Attendee::NeedsAction
-                  || me.status() == KCalendarCore::Attendee::Tentative
-                  || me.status() == KCalendarCore::Attendee::InProcess)) {
+                            || me.status() == KCalendarCore::Attendee::Tentative
+                            || me.status() == KCalendarCore::Attendee::InProcess)) {
         // Show the invitation bar: "You are invited [accept] [decline]"
         mUi->mInvitationBar->show();
     } else {
@@ -731,14 +746,6 @@ void IncidenceDialog::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "IncidenceDialog");
     group.writeEntry("Size", size());
-
-    const Akonadi::Collection col = d_ptr->mCalSelector->currentCollection();
-    // col might not be valid if the collection wasn't found yet (the combo is async), skip saving in that case
-    if (col.isValid()
-        && col.id() != IncidenceEditorNG::IncidenceEditorSettings::self()->lastSelectedFolder()) {
-        IncidenceEditorNG::IncidenceEditorSettings::self()->setLastSelectedFolder(col.id());
-        IncidenceEditorNG::IncidenceEditorSettings::self()->save();
-    }
 }
 
 void IncidenceDialog::readConfig()
@@ -768,11 +775,7 @@ void IncidenceDialog::load(const Akonadi::Item &item, const QDate &activeDate)
 void IncidenceDialog::selectCollection(const Akonadi::Collection &collection)
 {
     Q_D(IncidenceDialog);
-    if (collection.isValid()) {
-        d->mCalSelector->setDefaultCollection(collection);
-    } else {
-        d->mCalSelector->setCurrentIndex(0);
-    }
+    d->setCalendarCollection(collection);
 }
 
 void IncidenceDialog::setIsCounterProposal(bool isCounterProposal)
